from distutils.core import setup

setup(
             name='xkcc537',
             vsrsion='1.0.0',
             py_modules=['xkcc'],
             author='hfpython',
             author_email='chengcheng537@gmail.com',
             url='http://www.headfirstlabs.com',
             description='A simple printer of nested lists',
             )
